package com.zhiyun.common.model;

import com.zhiyun.common.constant.HttpStatus;

/**
 * 操作消息提醒
 */
public class ApiResult {
    /**
     * 状态码
     */
    public final int code;
    /**
     * 返回内容
     */
    public final String msg;
    /**
     * 数据对象
     */
    public final Object data;

    private ApiResult(int code, String msg, Object data) {
        this.code = code;
        this.msg = msg;
        this.data = data;
    }

    /**
     * 返回成功消息
     */
    public static ApiResult success() {
        return ApiResult.success("操作成功");
    }

    /**
     * 返回成功数据
     */
    public static ApiResult success(Object data) {
        return ApiResult.success("操作成功", data);
    }

    /**
     * 返回成功消息
     */
    public static ApiResult success(String msg) {
        return ApiResult.success(msg, msg);
    }

    /**
     * 返回成功消息
     */
    public static ApiResult success(String msg, Object data) {
        return new ApiResult(HttpStatus.SUCCESS, msg, data);
    }

    /**
     * 返回警告消息
     */
    public static ApiResult warn(String msg) {
        return ApiResult.warn(msg, null);
    }

    /**
     * 返回警告消息
     */
    public static ApiResult warn(String msg, Object data) {
        return new ApiResult(HttpStatus.WARN, msg, data);
    }

    /**
     * 返回错误消息
     */
    public static ApiResult error() {
        return ApiResult.error("操作失败");
    }

    /**
     * 返回错误消息
     */
    public static ApiResult error(String msg) {
        return ApiResult.error(msg, null);
    }

    /**
     * 返回错误消息
     */
    public static ApiResult error(String msg, Object data) {
        return new ApiResult(HttpStatus.ERROR, msg, data);
    }

    /**
     * 返回错误消息
     */
    public static ApiResult error(int code, String msg) {
        return new ApiResult(code, msg, null);
    }

}
