package com.zhiyun.common.model;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.zhiyun.common.utils.StringUtils;
import com.zhiyun.common.utils.sql.SqlUtil;
import com.zhiyun.framework.RoleDataScope;
import lombok.Data;

import java.util.Map;

/**
 * 分页数据
 *
 * @author ruoyi
 */
@Data
public class BaseBody {

    /**
     * 登录用户ID
     */
    private Long userId;

    /**
     * 数据权限
     */
    private Map<String, String> dataScope;

    /**
     * 当前记录起始索引
     */
    private Integer pageNum;

    /**
     * 每页显示记录数
     */
    private Integer pageSize;

    /**
     * 排序列
     */
    private String orderByColumn;

    /**
     * 排序的方向desc或者asc
     */
    private String sort = "asc";

    public String getOrderBy() {
        if (StringUtils.isEmpty(orderByColumn)) return "";
        return SqlUtil.escapeOrderBySql(StringUtils.toUnderScoreCase(orderByColumn) + " " + sort);
    }

    public void setSort(String sort) {
        if (StringUtils.isNotEmpty(sort)) {
            // 兼容前端排序类型
            if ("ascending".equals(sort)) {
                sort = "asc";
            } else if ("descending".equals(sort)) {
                sort = "desc";
            }
            this.sort = sort;
        }
    }

    /**
     * 获取SQL中用户过滤条件
     * 如果是管理员,则返回空,配合<if test></if> 标签
     */
    public Long getPremUserId() {
        if (RoleDataScope.isAdmin(userId)) {
            return null;
        }
        return userId;
    }

    public <T> Page<T> getPage() {
        return new Page<>(pageNum, pageSize);
    }

    public <T> Page<T> getNotPage() {
        return new Page<>(0, -1);
    }
}
