package com.zhiyun.framework;

import com.zhiyun.common.exception.UserException;
import com.zhiyun.common.utils.SecurityUtils;
import com.zhiyun.common.utils.StringUtils;
import com.zhiyun.project.item.domain.dto.Perm;
import com.zhiyun.project.system.domain.dto.LoginUser;
import com.zhiyun.project.system.domain.entity.SysRole;

/**
 * 数据过滤处理
 *
 * @author ruoyi
 */
public class RoleDataScope {
    /**
     * 全部数据权限
     */
    private static final String DATA_SCOPE_ALL = "1";

    /**
     * 自定数据权限
     */
    private static final String DATA_SCOPE_CUSTOM = "2";

    /**
     * 部门数据权限
     */
    private static final String DATA_SCOPE_DEPT = "3";

    /**
     * 部门及以下数据权限
     */
    private static final String DATA_SCOPE_DEPT_AND_CHILD = "4";

    public static Perm getDataScopePerm() {
        Perm perm = new Perm();
        LoginUser user = SecurityUtils.getLoginUser();
        if (user == null) {
            throw new UserException("获取当前登录用户信息失败");
        }
        // 如果是超级管理员，则不过滤数据
        if (isAdmin(user.getUserId()) || user.getUserId() <= 100) return perm;

        StringBuilder deptStr = new StringBuilder();
        StringBuilder itemStr = new StringBuilder();
        StringBuilder surveyStr = new StringBuilder();

        for (SysRole role : user.getRoles()) {
            //角色的数据权限
            String dataScope = role.getDataScope();

            //角色拥有全部数据权限
            if (DATA_SCOPE_ALL.equals(dataScope)) {
                return new Perm();
            }
            //角色拥有自定义权限
            else if (DATA_SCOPE_CUSTOM.equals(dataScope)) {
                deptStr.append(StringUtils.format("SELECT dept_id FROM sys_role_dept WHERE role_id = {} UNION ", role.getRoleId()));
                itemStr.append(StringUtils.format("SELECT mine_id FROM sys_dept_mine WHERE dept_id IN (SELECT dept_id FROM sys_role_dept WHERE role_id = {}) UNION ", role.getRoleId()));
                surveyStr.append(StringUtils.format("SELECT areagroup FROM survey_area WHERE mine_id IN (SELECT mine_id FROM sys_dept_mine WHERE dept_id IN (SELECT dept_id FROM sys_role_dept WHERE role_id = {})) UNION ", role.getRoleId()));
            }

            //部门权限
            else if (DATA_SCOPE_DEPT.equals(dataScope)) {
                deptStr.append(StringUtils.format("SELECT {} FROM DUAL UNION ", user.getDeptId()));
                itemStr.append(StringUtils.format("SELECT mine_id FROM sys_dept_mine WHERE dept_id = {} UNION ", user.getDeptId()));
                surveyStr.append(StringUtils.format("SELECT areagroup FROM survey_area WHERE mine_id IN (SELECT mine_id FROM sys_dept_mine WHERE dept_id = {}) UNION ", user.getDeptId()));
            }

            //部门及其子部门权限
            else if (DATA_SCOPE_DEPT_AND_CHILD.equals(dataScope)) {
                deptStr.append(StringUtils.format("SELECT dept_id FROM sys_dept WHERE dept_id = {} or find_in_set({},ancestors) UNION ", user.getDeptId(), user.getDeptId()));
                itemStr.append(StringUtils.format("SELECT mine_id FROM sys_dept_mine WHERE dept_id IN (SELECT dept_id FROM sys_dept WHERE dept_id = {} or find_in_set({},ancestors)) UNION ", user.getDeptId(), user.getDeptId()));
                surveyStr.append(StringUtils.format("SELECT areagroup FROM survey_area WHERE mine_id IN (SELECT mine_id FROM sys_dept_mine WHERE dept_id IN (SELECT dept_id FROM sys_dept WHERE dept_id = {} or find_in_set({},ancestors))) UNION ", user.getDeptId(), user.getDeptId()));
            }
        }
        //部门
        String deptScope = deptStr.toString();
        if (StringUtils.isNotBlank(deptScope)) {
            perm.setDept(deptScope.substring(0, deptScope.length() - 7));
        }

        //部门
        String itemScope = itemStr.toString();
        if (StringUtils.isNotBlank(deptScope)) {
            perm.setItem(itemScope.substring(0, itemScope.length() - 7));
        }

        //测区
        String surveyScope = surveyStr.toString();
        if (StringUtils.isNotBlank(surveyScope)) {
            perm.setSurvey(surveyScope.substring(0, surveyScope.length() - 7));
        }

        return perm;
    }


    public static boolean isAdmin(Long userId) {
        return userId != null && userId == 1;
    }

    public static boolean isAdminRole(Long roleId) {
        return roleId != null && roleId == 1;
    }
}
