package com.zhiyun.framework.manager.factory;

import com.google.common.collect.Sets;
import com.zhiyun.common.constant.Constants;
import com.zhiyun.common.utils.ServletUtils;
import com.zhiyun.common.utils.ip.AddressUtils;
import com.zhiyun.common.utils.ip.IpUtils;
import com.zhiyun.common.utils.spring.SpringUtils;
import com.zhiyun.project.monitor.domain.SysLoginInfo;
import com.zhiyun.project.monitor.domain.SysOperLog;
import com.zhiyun.project.monitor.service.ISysLoginInfoService;
import com.zhiyun.project.monitor.service.ISysOperLogService;
import eu.bitwalker.useragentutils.UserAgent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Set;
import java.util.TimerTask;

/**
 * 异步工厂（产生任务用）
 *
 * @author ruoyi
 */
public class AsyncFactory {

    private static final Logger sys_user_logger = LoggerFactory.getLogger("sys-user");

    private static final Set<String> SUCCESS_SET = Sets.newHashSet(Constants.LOGIN_SUCCESS, Constants.LOGOUT, Constants.REGISTER);

    /**
     * 记录登录信息
     *
     * @param username 用户名
     * @param status   状态
     * @param message  消息
     * @param args     列表
     * @return 任务task
     */
    public static TimerTask recordLoginInfo(final String username, final String status, final String message, final Object... args) {
        final UserAgent userAgent = UserAgent.parseUserAgentString(ServletUtils.getRequest().getHeader("User-Agent"));
        final String ip = IpUtils.getIpAddress(ServletUtils.getRequest());
        return new TimerTask() {
            @Override
            public void run() {
                String address = AddressUtils.getRealAddressByIP(ip);
                String s = getBlock(ip) + address + getBlock(username) + getBlock(status) + getBlock(message);
                // 打印信息到日志
                sys_user_logger.info(s, args);
                // 封装对象
                SysLoginInfo loginInfo = new SysLoginInfo();
                loginInfo.setUserName(username);
                loginInfo.setIpaddr(ip);
                loginInfo.setLoginLocation(address);
                // 获取客户端浏览器
                loginInfo.setBrowser(userAgent.getBrowser().getName());
                // 获取客户端操作系统
                loginInfo.setOs(userAgent.getOperatingSystem().getName());
                loginInfo.setMsg(message);
                // 日志状态
                loginInfo.setStatus(SUCCESS_SET.contains(status) ? Constants.SUCCESS : Constants.FAIL);
                // 插入数据
                SpringUtils.getBean(ISysLoginInfoService.class).save(loginInfo);
            }
        };
    }

    /**
     * 操作日志记录
     *
     * @param operLog 操作日志信息
     * @return 任务task
     */
    public static TimerTask recordOperateInfo(final SysOperLog operLog) {
        return new TimerTask() {
            @Override
            public void run() {
                // 远程查询操作地点
                operLog.setOperLocation(AddressUtils.getRealAddressByIP(operLog.getOperIp()));
                SpringUtils.getBean(ISysOperLogService.class).save(operLog);
            }
        };
    }

    private static String getBlock(Object msg) {
        if (msg == null) {
            msg = "";
        }
        return "[" + msg + "]";
    }
}
