package com.zhiyun.framework.web;

import com.zhiyun.framework.RoleDataScope;
import com.zhiyun.project.system.service.ISysMenuService;
import com.zhiyun.project.system.service.ISysRoleService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.HashSet;
import java.util.Set;

/**
 * 用户权限处理
 *
 * @author ruoyi
 */
@Slf4j
@Component
public class SysPermissionService {

    @Autowired
    private ISysRoleService roleService;
    @Autowired
    private ISysMenuService menuService;

    /**
     * 获取角色数据权限
     */
    public Set<String> getRolePermission(Long userId) {
        Set<String> roles = new HashSet<>();
        // 管理员拥有所有权限
        if (RoleDataScope.isAdmin(userId)) {
            roles.add("admin");
        } else {
            roles.addAll(roleService.selectRolePermissionByUserId(userId));
        }
        return roles;
    }

    /**
     * 获取菜单数据权限
     */
    public Set<String> getMenuPermissionByUserId(Long userId) {
        Set<String> perms = new HashSet<>();
        // 管理员拥有所有权限
        if (RoleDataScope.isAdmin(userId)) {
            perms.add("*:*:*");
        } else {
            perms.addAll(menuService.selectMenuPermsByUserId(userId));
        }
        return perms;
    }

    /**
     * 获取菜单数据权限
     */
    public Set<String> getMenuPermissionByRoleId(Long roleId) {
        return menuService.selectMenuPermsByRoleId(roleId);
    }


}
