package com.zhiyun.framework.web;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.zhiyun.common.enums.UserStatus;
import com.zhiyun.common.exception.UserException;
import com.zhiyun.project.system.domain.dto.LoginUser;
import com.zhiyun.project.system.domain.entity.SysDept;
import com.zhiyun.project.system.domain.entity.SysRole;
import com.zhiyun.project.system.domain.entity.SysUser;
import com.zhiyun.project.system.service.ISysDeptService;
import com.zhiyun.project.system.service.ISysRoleService;
import com.zhiyun.project.system.service.ISysUserService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 用户验证处理
 *
 * @author ruoyi
 */
@Slf4j
@Service
public class UserDetailsServiceImpl implements UserDetailsService {

    @Autowired
    private ISysUserService userService;
    @Autowired
    private ISysDeptService deptService;
    @Autowired
    private ISysRoleService roleService;
    @Autowired
    private SysPermissionService permissionService;

    @Override
    public UserDetails loadUserByUsername(String username) throws UsernameNotFoundException {
        SysUser user = userService.getOne(new QueryWrapper<SysUser>().eq("user_name", username));
        if (user == null) {
            log.info("登录用户：{} 不存在.", username);
            throw new UserException("登录用户：" + username + " 不存在");
        } else if (UserStatus.DISABLE.getCode().equals(user.getStatus())) {
            log.info("登录用户：{} 已被停用.", username);
            throw new UserException("对不起，您的账号：" + username + " 已停用");
        }
        return createLoginUser(user);
    }

    private UserDetails createLoginUser(SysUser user) {
        LoginUser loginUser = new LoginUser();
        loginUser.setUserId(user.getUserId());
        loginUser.setDeptId(user.getDeptId());
        loginUser.setUser(user);
        //角色
        List<SysRole> roles = roleService.selectRolesByUserId(user.getUserId());
        //角色的菜单权限
        roles.forEach(item -> item.setMenuPermission(permissionService.getMenuPermissionByRoleId(item.getRoleId())));
        loginUser.setRoles(roles);
        //设置用户的菜单权限
        loginUser.setMenuPermissions(permissionService.getMenuPermissionByUserId(user.getUserId()));
        //部门
        SysDept dept = deptService.getById(user.getDeptId());
        loginUser.setDept(dept);
        loginUser.setMineId(dept.getMineId());
        return loginUser;
    }


}
