package com.zhiyun.project.common;

import com.zhiyun.common.model.ApiResult;
import com.zhiyun.common.utils.DateUtils;
import com.zhiyun.common.utils.SecurityUtils;
import com.zhiyun.project.system.domain.dto.LoginUser;
import org.springframework.web.bind.WebDataBinder;
import org.springframework.web.bind.annotation.InitBinder;

import java.beans.PropertyEditorSupport;
import java.util.Date;

/**
 * web层通用数据处理
 *
 * @author ruoyi
 */
public class BaseController {

    /**
     * 将前台传递过来的日期格式的字符串，自动转化为Date类型
     */
    @InitBinder
    public void initBinder(WebDataBinder binder) {
        // Date 类型转换
        binder.registerCustomEditor(Date.class, new PropertyEditorSupport() {
            @Override
            public void setAsText(String text) {
                setValue(DateUtils.parseDate(text));
            }
        });
    }

    /**
     * 响应返回结果
     */
    protected ApiResult toApiResult(int rows) {
        return rows > 0 ? ApiResult.success() : ApiResult.error();
    }

    /**
     * 响应返回结果
     */
    protected ApiResult toApiResult(boolean result) {
        return result ? ApiResult.success() : ApiResult.error();
    }

    /**
     * 获取用户缓存信息
     */
    public LoginUser getLoginUser() {
        return SecurityUtils.getLoginUser();
    }

    /**
     * 获取登录用户id
     */
    public Long getUserId() {
        return getLoginUser().getUserId();
    }

    /**
     * 获取登录用户名
     */
    public String getUsername() {
        return getLoginUser().getUsername();
    }
}
