package com.zhiyun.project.monitor.controller;

import com.zhiyun.common.annotation.Log;
import com.zhiyun.common.constant.CacheConstants;
import com.zhiyun.common.core.redis.RedisCache;
import com.zhiyun.common.enums.BusinessType;
import com.zhiyun.common.model.ApiResult;
import com.zhiyun.common.model.TableResult;
import com.zhiyun.project.common.BaseController;
import com.zhiyun.project.monitor.domain.body.LoginInfoBody;
import com.zhiyun.project.monitor.service.ISysLoginInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.stream.Collectors;

/**
 * 系统访问记录
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/monitor/logininfor")
public class SysLoginInfoController extends BaseController {

    @Autowired
    private ISysLoginInfoService loginInfoService;
    @Autowired
    private RedisCache redisCache;

    @PreAuthorize("@ss.hasPermi('monitor:logininfor:list')")
    @GetMapping("/list")
    public TableResult list(LoginInfoBody body) {
        return TableResult.getTableResult(loginInfoService.pageLoginInfo(body));
    }

    @PreAuthorize("@ss.hasPermi('monitor:logininfor:remove')")
    @Log(title = "登录日志", businessType = BusinessType.DELETE)
    @DeleteMapping("/{infoIds}")
    public ApiResult remove(@PathVariable Long[] infoIds) {
        return toApiResult(loginInfoService.removeBatchByIds(Arrays.stream(infoIds).collect(Collectors.toSet())));
    }

    @PreAuthorize("@ss.hasPermi('monitor:logininfor:remove')")
    @Log(title = "登录日志", businessType = BusinessType.CLEAN)
    @DeleteMapping("/clean")
    public ApiResult clean() {
        loginInfoService.cleanLoginInfo();
        return ApiResult.success();
    }

    @PreAuthorize("@ss.hasPermi('monitor:logininfor:unlock')")
    @Log(title = "账户解锁", businessType = BusinessType.OTHER)
    @GetMapping("/unlock/{userName}")
    public ApiResult unlock(@PathVariable("userName") String userName) {
        redisCache.deleteObject(CacheConstants.PWD_ERR_CNT_KEY + userName);
        return ApiResult.success();
    }
}
