package com.zhiyun.project.monitor.controller;

import com.zhiyun.common.annotation.Log;
import com.zhiyun.common.enums.BusinessType;
import com.zhiyun.common.model.ApiResult;
import com.zhiyun.common.model.TableResult;
import com.zhiyun.project.common.BaseController;
import com.zhiyun.project.monitor.domain.body.OperLogBody;
import com.zhiyun.project.monitor.service.ISysOperLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.stream.Collectors;

/**
 * 操作日志记录
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/monitor/operlog")
public class SysOperlogController extends BaseController {
    @Autowired
    private ISysOperLogService operLogService;

    @PreAuthorize("@ss.hasPermi('monitor:operlog:list')")
    @GetMapping("/list")
    public TableResult list(OperLogBody body) {
        return TableResult.getTableResult(operLogService.selectOperLogPage(body));
    }

    @Log(title = "操作日志", businessType = BusinessType.DELETE)
    @PreAuthorize("@ss.hasPermi('monitor:operlog:remove')")
    @DeleteMapping("/{operIds}")
    public ApiResult remove(@PathVariable Long[] operIds) {
        return toApiResult(operLogService.removeBatchByIds(Arrays.stream(operIds).collect(Collectors.toSet())));
    }

    @Log(title = "操作日志", businessType = BusinessType.CLEAN)
    @PreAuthorize("@ss.hasPermi('monitor:operlog:remove')")
    @DeleteMapping("/clean")
    public ApiResult clean() {
        operLogService.cleanOperLog();
        return ApiResult.success();
    }
}
