package com.zhiyun.project.system.controller;

import com.zhiyun.common.annotation.Log;
import com.zhiyun.common.constant.UserConstants;
import com.zhiyun.common.enums.BusinessType;
import com.zhiyun.common.model.ApiResult;
import com.zhiyun.common.model.TableResult;
import com.zhiyun.project.common.BaseController;
import com.zhiyun.project.system.domain.body.SysConfigBody;
import com.zhiyun.project.system.domain.entity.SysConfig;
import com.zhiyun.project.system.service.ISysConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 参数配置 信息操作处理
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/system/config")
public class SysConfigController extends BaseController {
    @Autowired
    private ISysConfigService configService;

    /**
     * 获取参数配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:config:list')")
    @GetMapping("/list")
    public TableResult list(SysConfigBody body) {
        return TableResult.getTableResult(configService.selectConfigPage(body));
    }

    /**
     * 根据参数编号获取详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:config:query')")
    @GetMapping(value = "/{configId}")
    public ApiResult getInfo(@PathVariable Long configId) {
        return ApiResult.success(configService.getById(configId));
    }

    /**
     * 根据参数键名查询参数值
     */
    @GetMapping(value = "/configKey/{configKey}")
    public ApiResult getConfigKey(@PathVariable String configKey) {
        return ApiResult.success(configService.selectConfigByKey(configKey));
    }

    /**
     * 新增参数配置
     */
    @PreAuthorize("@ss.hasPermi('system:config:add')")
    @Log(title = "参数管理", businessType = BusinessType.INSERT)
    @PostMapping
    public ApiResult add(@Validated @RequestBody SysConfig config) {
        if (configService.checkConfigKeyUnique(null, config.getConfigKey()).equals(UserConstants.NOT_UNIQUE)) {
            return ApiResult.error("新增参数'" + config.getConfigName() + "'失败，参数键名已存在");
        }
        config.setCreateBy(getUsername());
        return toApiResult(configService.insertConfig(config));
    }

    /**
     * 修改参数配置
     */
    @PreAuthorize("@ss.hasPermi('system:config:edit')")
    @Log(title = "参数管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public ApiResult edit(@Validated @RequestBody SysConfig config) {
        if (configService.checkConfigKeyUnique(config.getConfigId(), config.getConfigKey()).equals(UserConstants.NOT_UNIQUE)) {
            return ApiResult.error("修改参数'" + config.getConfigName() + "'失败，参数键名已存在");
        }
        config.setUpdateBy(getUsername());
        return toApiResult(configService.updateConfig(config));
    }

    /**
     * 删除参数配置
     */
    @PreAuthorize("@ss.hasPermi('system:config:remove')")
    @Log(title = "参数管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{configIds}")
    public ApiResult remove(@PathVariable Long[] configIds) {
        configService.deleteConfigByIds(configIds);
        return ApiResult.success();
    }

    /**
     * 刷新参数缓存
     */
    @PreAuthorize("@ss.hasPermi('system:config:remove')")
    @Log(title = "参数管理", businessType = BusinessType.CLEAN)
    @DeleteMapping("/refreshCache")
    public ApiResult refreshCache() {
        configService.resetConfigCache();
        return ApiResult.success();
    }
}
