package com.zhiyun.project.system.controller;

import com.zhiyun.common.model.ApiResult;
import com.zhiyun.common.utils.SecurityUtils;
import com.zhiyun.framework.web.SysPermissionService;
import com.zhiyun.project.system.domain.RouteBuilder;
import com.zhiyun.project.system.domain.body.LoginBody;
import com.zhiyun.project.system.domain.entity.SysUser;
import com.zhiyun.project.system.domain.vo.SysMenuVo;
import com.zhiyun.project.system.service.ISysMenuService;
import com.zhiyun.project.system.service.impl.SysLoginService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 登录验证
 *
 * @author ruoyi
 */
@RestController
public class SysLoginController {
    @Autowired
    private SysLoginService loginService;

    @Autowired
    private ISysMenuService menuService;

    @Autowired
    private SysPermissionService permissionService;

    /**
     * 登录方法
     *
     * @param loginBody 登录信息
     * @return 结果
     */
    @PostMapping("/login")
    public ApiResult login(@RequestBody LoginBody loginBody) {
        // 生成令牌
        String token = loginService.login(loginBody.getUsername(), loginBody.getPassword(), loginBody.getCode(), loginBody.getUuid());
        Map<String, Object> result = new HashMap<>();
        result.put("token", token);
        return ApiResult.success(result);
    }

    /**
     * 获取用户信息
     *
     * @return 用户信息
     */
    @GetMapping("getInfo")
    public ApiResult getInfo() {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        // 角色集合
        Set<String> roles = permissionService.getRolePermission(user.getUserId());
        // 权限集合
        Set<String> permissions = permissionService.getMenuPermissionByUserId(user.getUserId());
        Map<String, Object> result = new HashMap<>();
        result.put("user", user);
        result.put("roles", roles);
        result.put("permissions", permissions);
        return ApiResult.success(result);
    }

    /**
     * 获取路由信息
     *
     * @return 路由信息
     */
    @GetMapping("getRouters")
    public ApiResult getRouters() {
        Long userId = SecurityUtils.getUserId();
        List<SysMenuVo> menus = menuService.selectMenuTreeByUserId(userId);
        return ApiResult.success(RouteBuilder.buildMenus(menus));
    }
}
