package com.zhiyun.project.system.controller;

import com.zhiyun.common.annotation.Log;
import com.zhiyun.common.enums.BusinessType;
import com.zhiyun.common.model.ApiResult;
import com.zhiyun.common.model.TableResult;
import com.zhiyun.project.common.BaseController;
import com.zhiyun.project.system.domain.body.SysNoticeBody;
import com.zhiyun.project.system.domain.entity.SysNotice;
import com.zhiyun.project.system.service.ISysNoticeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.stream.Collectors;

/**
 * 公告 信息操作处理
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/system/notice")
public class SysNoticeController extends BaseController {
    @Autowired
    private ISysNoticeService noticeService;

    /**
     * 获取通知公告列表
     */
    @PreAuthorize("@ss.hasPermi('system:notice:list')")
    @GetMapping("/list")
    public TableResult list(SysNoticeBody body) {
        return TableResult.getTableResult(noticeService.selectNoticeList(body));
    }

    /**
     * 根据通知公告编号获取详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:notice:query')")
    @GetMapping(value = "/{noticeId}")
    public ApiResult getInfo(@PathVariable Long noticeId) {
        return ApiResult.success(noticeService.getById(noticeId));
    }

    /**
     * 新增通知公告
     */
    @PreAuthorize("@ss.hasPermi('system:notice:add')")
    @Log(title = "通知公告", businessType = BusinessType.INSERT)
    @PostMapping
    public ApiResult add(@Validated @RequestBody SysNotice notice) {
        notice.setCreateBy(getUsername());
        return toApiResult(noticeService.save(notice));
    }

    /**
     * 修改通知公告
     */
    @PreAuthorize("@ss.hasPermi('system:notice:edit')")
    @Log(title = "通知公告", businessType = BusinessType.UPDATE)
    @PutMapping
    public ApiResult edit(@Validated @RequestBody SysNotice notice) {
        notice.setUpdateBy(getUsername());
        return toApiResult(noticeService.updateById(notice));
    }

    /**
     * 删除通知公告
     */
    @PreAuthorize("@ss.hasPermi('system:notice:remove')")
    @Log(title = "通知公告", businessType = BusinessType.DELETE)
    @DeleteMapping("/{noticeIds}")
    public ApiResult remove(@PathVariable Long[] noticeIds) {
        return toApiResult(noticeService.removeBatchByIds(Arrays.stream(noticeIds).collect(Collectors.toList())));
    }
}
