package com.zhiyun.project.system.controller;

import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.zhiyun.common.annotation.Log;
import com.zhiyun.common.constant.UserConstants;
import com.zhiyun.common.enums.BusinessType;
import com.zhiyun.common.model.ApiResult;
import com.zhiyun.common.utils.SecurityUtils;
import com.zhiyun.common.utils.StringUtils;
import com.zhiyun.common.utils.file.FileUploadUtils;
import com.zhiyun.common.utils.file.MimeTypeUtils;
import com.zhiyun.framework.config.ZySystemConfig;
import com.zhiyun.framework.web.TokenService;
import com.zhiyun.project.common.BaseController;
import com.zhiyun.project.system.domain.dto.LoginUser;
import com.zhiyun.project.system.domain.entity.SysUser;
import com.zhiyun.project.system.service.ISysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.HashMap;
import java.util.Map;

/**
 * 个人信息 业务处理
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/system/user/profile")
public class SysProfileController extends BaseController {
    @Autowired
    private ISysUserService userService;

    @Autowired
    private TokenService tokenService;

    /**
     * 个人信息
     */
    @GetMapping
    public ApiResult profile() {
        LoginUser loginUser = getLoginUser();
        Map<String, Object> result = new HashMap<>();
        result.put("user", loginUser.getUser());
        result.put("dept", loginUser.getDept());
        result.put("roleGroup", userService.selectUserRoleGroup(loginUser.getUsername()));
        return ApiResult.success(result);
    }

    /**
     * 修改用户
     */
    @Log(title = "个人信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ApiResult updateProfile(@RequestBody SysUser user) {
        LoginUser loginUser = getLoginUser();
        SysUser crtUser = loginUser.getUser();
        if (StringUtils.isNotEmpty(user.getPhonenumber())
                && UserConstants.NOT_UNIQUE.equals(userService.checkPhoneUnique(crtUser.getUserId(), user.getPhonenumber()))) {
            return ApiResult.error("修改用户'" + user.getUserName() + "'失败，手机号码已存在");
        }
        if (StringUtils.isNotEmpty(user.getEmail())
                && UserConstants.NOT_UNIQUE.equals(userService.checkEmailUnique(crtUser.getUserId(), user.getEmail()))) {
            return ApiResult.error("修改用户'" + user.getUserName() + "'失败，邮箱账号已存在");
        }
        user.setUserId(crtUser.getUserId());
        user.setPassword(null);
        user.setAvatar(null);
        user.setDeptId(null);
        if (userService.updateById(user)) {
            // 更新缓存用户信息
            crtUser.setNickName(user.getNickName());
            crtUser.setPhonenumber(user.getPhonenumber());
            crtUser.setEmail(user.getEmail());
            crtUser.setSex(user.getSex());
            tokenService.setLoginUser(loginUser);
            return ApiResult.success();
        }
        return ApiResult.error("修改个人信息异常，请联系管理员");
    }

    /**
     * 重置密码
     */
    @Log(title = "个人信息", businessType = BusinessType.UPDATE)
    @PutMapping("/updatePwd")
    public ApiResult updatePwd(String oldPassword, String newPassword) {
        LoginUser loginUser = getLoginUser();
        Long userId = loginUser.getUserId();
        String password = loginUser.getPassword();
        if (!SecurityUtils.matchesPassword(oldPassword, password)) {
            return ApiResult.error("修改密码失败，旧密码错误");
        }
        if (SecurityUtils.matchesPassword(newPassword, password)) {
            return ApiResult.error("新密码不能与旧密码相同");
        }
        SysUser user = new SysUser();
        user.setUserId(userId);
        user.setPassword(SecurityUtils.encryptPassword(newPassword));
        if (userService.updateById(user)) {
            // 更新缓存用户密码
            loginUser.getUser().setPassword(SecurityUtils.encryptPassword(newPassword));
            tokenService.setLoginUser(loginUser);
            return ApiResult.success();
        }
        return ApiResult.error("修改密码异常，请联系管理员");
    }

    /**
     * 头像上传
     */
    @Log(title = "用户头像", businessType = BusinessType.UPDATE)
    @PostMapping("/avatar")
    public ApiResult avatar(@RequestParam("avatarfile") MultipartFile file) throws Exception {
        if (!file.isEmpty()) {
            LoginUser loginUser = getLoginUser();
            String avatar = FileUploadUtils.upload(ZySystemConfig.getAvatarPath(), file, MimeTypeUtils.IMAGE_EXTENSION);

            if (userService.update(new UpdateWrapper<SysUser>().set("avatar", avatar).eq("user_id", loginUser.getUserId()))) {
                // 更新缓存用户头像
                loginUser.getUser().setAvatar(avatar);
                tokenService.setLoginUser(loginUser);

                Map<String, Object> result = new HashMap<>();
                result.put("imgUrl", avatar);
                return ApiResult.success(result);
            }
        }
        return ApiResult.error("上传图片异常，请联系管理员");
    }
}
