package com.zhiyun.project.system.controller;

import com.zhiyun.common.annotation.Anonymous;
import com.zhiyun.common.annotation.Log;
import com.zhiyun.common.enums.BusinessType;
import com.zhiyun.common.model.ApiResult;
import com.zhiyun.project.common.BaseController;
import com.zhiyun.project.system.service.ISysVxService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * vx用户信息
 *
 * @author LYW
 */
@Anonymous
@RestController
@RequestMapping("/system/vx")
public class SysVxController extends BaseController {

    @Autowired
    private ISysVxService sysVxService;

    /**
     * 查询绑定vx用户的用户
     */
    @PreAuthorize("@ss.hasPermi('system:user:edit')")
    @Log(title = "用户绑定", businessType = BusinessType.UPDATE)
    @GetMapping("/getBindUser")
    public ApiResult getBindUser() {
        return ApiResult.success(sysVxService.getBindUser());
    }

    /**
     * 查询当前账号绑定的vx用户
     */
    @GetMapping("/getVxUser")
    public ApiResult getVxUser(String userName) {
        return ApiResult.success(sysVxService.getVxUser(userName));
    }

    /**
     * 更新对应userName为空
     */
    @PostMapping("/setUserName")
    public ApiResult setUserName(String userName) {
        return toApiResult(sysVxService.setUserName(userName));
    }

    /**
     * 查出所有未绑定的vx用户
     */
    @GetMapping("/getVxUsers")
    public ApiResult getVxUsers() {
        return ApiResult.success(sysVxService.getVxUsers());
    }

    /**
     * 给vx用户绑定系统用户
     */
    @PostMapping("/setVxUser")
    public ApiResult setVxUser(String vxUser, String userName) {
        return toApiResult(sysVxService.setVxUser(vxUser, userName));
    }

}
