package com.zhiyun.project.system.domain.dto;

import com.zhiyun.project.system.domain.entity.SysDept;
import com.zhiyun.project.system.domain.entity.SysRole;
import com.zhiyun.project.system.domain.entity.SysUser;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;

import java.util.Collection;
import java.util.List;
import java.util.Set;

/**
 * 登录用户身份权限
 *
 * @author ruoyi
 */
@Data
@NoArgsConstructor
public class LoginUser implements UserDetails {
    private static final long serialVersionUID = 1L;

    private Integer item;
    /**
     * 用户ID
     */
    private Long userId;

    /**
     * 部门ID
     */
    private Long deptId;

    /**
     * 矿区ID
     */
    private Integer mineId;

    /**
     * token相关
     */
    //用户唯一标识
    private String token;
    //登录时间
    private Long loginTime;
    //过期时间
    private Long expireTime;

    /**
     * 用户设备信息
     */
    //登录IP地址
    private String ipaddr;
    //登录地点
    private String loginLocation;
    //浏览器类型
    private String browser;
    //操作系统
    private String os;

    /**
     * 权限列表
     */
    private Set<String> menuPermissions;

    /**
     * 角色对象
     */
    private List<SysRole> roles;

    /**
     * 用户信息
     */
    private SysUser user;

    /**
     * 部门信息
     */
    private SysDept dept;

    @Override
    public String getPassword() {
        return user.getPassword();
    }

    @Override
    public String getUsername() {
        return user.getUserName();
    }


    //以下方法暂时无用

    /**
     * 账户是否未过期,过期无法验证
     */
    @Override
    public boolean isAccountNonExpired() {
        return true;
    }

    /**
     * 指定用户是否解锁,锁定的用户无法进行身份验证
     */
    @Override
    public boolean isAccountNonLocked() {
        return true;
    }

    /**
     * 指示是否已过期的用户的凭据(密码),过期的凭据防止认证
     */
    @Override
    public boolean isCredentialsNonExpired() {
        return true;
    }

    /**
     * 是否可用 ,禁用的用户不能身份验证
     */
    @Override
    public boolean isEnabled() {
        return true;
    }

    @Override
    public Collection<? extends GrantedAuthority> getAuthorities() {
        return null;
    }
}
