package com.zhiyun.project.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;

import com.zhiyun.project.item.domain.dto.Perm;
import com.zhiyun.project.system.domain.body.SysDeptBody;
import com.zhiyun.project.system.domain.entity.SysDept;
import com.zhiyun.project.system.domain.vo.SysDeptVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 部门管理 数据层
 *
 * @author ruoyi
 */
public interface SysDeptMapper extends BaseMapper<SysDept> {
    /**
     * 查询部门管理数据
     *
     * @param param 部门信息
     */
    List<SysDeptVo> selectDeptList(@Param("perm") Perm perm, @Param("param") SysDeptBody param);

    /**
     * 根据角色ID查询部门树信息
     *
     * @param roleId            角色ID
     * @return 选中部门列表
     */
    List<Long> selectDeptListByRoleId(@Param("roleId") Long roleId);

    /**
     * 根据部门ID查询信息
     *
     * @param deptId 部门ID
     * @return 部门信息
     */
    SysDeptVo selectDeptById(Long deptId);

    /**
     * 根据ID查询所有子部门
     *
     * @param deptId 部门ID
     * @return 部门列表
     */
    List<SysDept> selectChildrenDeptById(Long deptId);

    /**
     * 根据ID查询所有子部门（正常状态）
     *
     * @param deptId 部门ID
     * @return 子部门数
     */
    int countNormalChildDeptById(Long deptId);

    /**
     * 是否存在子节点
     *
     * @param deptId 部门ID
     * @return 结果
     */
    int hasChildByDeptId(Long deptId);

    /**
     * 查询部门是否存在用户
     *
     * @param deptId 部门ID
     */
    int checkDeptExistUser(Long deptId);

    /**
     * 校验部门名称是否唯一
     *
     * @param deptName 部门名称
     * @param parentId 父部门ID
     * @return 结果
     */
    Long checkDeptNameUnique(@Param("deptName") String deptName, @Param("parentId") Long parentId);

    /**
     * 修改所在部门正常状态
     */
    void updateDeptStatusNormal(Long[] deptIds);

    /**
     * 修改子元素关系
     */
    int updateDeptChildren(@Param("depts") List<SysDept> depts);

    /**
     * 删除部门管理信息
     * 逻辑删除
     */
    int deleteDeptById(Long deptId);
}
