package com.zhiyun.project.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.zhiyun.project.system.domain.body.SysMenuBody;
import com.zhiyun.project.system.domain.entity.SysMenu;
import com.zhiyun.project.system.domain.vo.SysMenuVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 菜单表 数据层
 *
 * @author ruoyi
 */
public interface SysMenuMapper extends BaseMapper<SysMenu> {
    /**
     * 查询系统菜单列表
     *
     * @param param 菜单信息
     */
    List<SysMenuVo> selectMenuList(@Param("param") SysMenuBody param);

    /**
     * 根据角色ID查询权限
     *
     * @param roleId 角色ID
     */
    List<String> selectMenuPermsByRoleId(Long roleId);

    /**
     * 根据用户ID查询权限
     *
     * @param userId 用户ID
     */
    List<String> selectMenuPermsByUserId(Long userId);

    /**
     * 根据用户ID查询菜单
     *
     * @param userId 用户ID
     */
    List<SysMenuVo> selectMenuTree(Long userId);

    /**
     * 根据角色ID查询菜单树信息
     *
     * @param roleId            角色ID
     * @param menuCheckStrictly 菜单树选择项是否关联显示
     * @return 选中菜单列表
     */
    List<Long> selectMenuIdListByRoleId(@Param("roleId") Long roleId, @Param("menuCheckStrictly") boolean menuCheckStrictly);

    /**
     * 是否存在菜单子节点
     *
     * @param menuId 菜单ID
     * @return 结果
     */
    int hasChildByMenuId(Long menuId);

    /**
     * 校验菜单名称是否唯一
     *
     * @param menuName 菜单名称
     * @param parentId 父菜单ID
     */
    Long checkMenuNameUnique(@Param("menuName") String menuName, @Param("parentId") Long parentId);
}
