package com.zhiyun.project.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.zhiyun.project.item.domain.dto.Perm;
import com.zhiyun.project.system.domain.body.SysUserBody;
import com.zhiyun.project.system.domain.entity.SysUser;
import com.zhiyun.project.system.domain.vo.SysUserVo;
import com.zhiyun.project.system.domain.vo.UserActiveVo;
import org.apache.ibatis.annotations.Param;

/**
 * 用户表 数据层
 *
 * @author ruoyi
 */
public interface SysUserMapper extends BaseMapper<SysUser> {
    /**
     * 根据条件分页查询用户列表
     */
    Page<SysUserVo> selectUserList(Page<SysUserVo> page, @Param("perm") Perm perm, @Param("param") SysUserBody param);

    /**
     * 根据条件分页查询已配用户角色列表
     */
    Page<SysUserVo> selectAllocatedList(Page<SysUserVo> page, @Param("perm") Perm perm, @Param("param") SysUserBody param);

    /**
     * 根据条件分页查询未分配用户角色列表
     */
    Page<SysUserVo> selectUnallocatedList(Page<SysUserVo> page, @Param("perm") Perm perm, @Param("param") SysUserBody param);

    /**
     * 通过用户名查询用户
     */
    SysUserVo selectUserByUserName(String userName);

    /**
     * 通过用户ID查询用户
     */
    SysUserVo selectUserById(Long userId);

    /**
     * 批量删除用户信息
     *
     * @param userIds 需要删除的用户ID
     */
    int deleteUserByIds(Long[] userIds);

    /**
     * 校验用户名称是否唯一
     */
    int checkUserNameUnique(@Param("userId") Long userId, @Param("userName") String userName);

    /**
     * 校验手机号码是否唯一
     */
    int checkPhoneUnique(@Param("userId") Long userId, @Param("phonenumber") String phonenumber);

    /**
     * 校验email是否唯一
     */
    int checkEmailUnique(@Param("userId") Long userId, @Param("email") String email);

    /**
     * 查询用户是否有权限
     *
     * @param operatedUserId 被操作的用户ID
     */
    int checkUserDataScope(@Param("operatedUserId") Long operatedUserId, @Param("perm") Perm perm);

    /**
     * 查询用户活跃状态
     */
    UserActiveVo getUserActive(@Param("perm") Perm perm);
}
