package com.zhiyun.project.system.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.zhiyun.project.system.domain.body.SysUserBody;
import com.zhiyun.project.system.domain.entity.SysUser;
import com.zhiyun.project.system.domain.vo.SysUserVo;
import com.zhiyun.project.system.domain.vo.UserActiveVo;

/**
 * 用户 业务层
 *
 * @author ruoyi
 */
public interface ISysUserService extends IService<SysUser> {
    /**
     * 根据条件分页查询用户列表
     */
    Page<SysUserVo> selectUserPage(SysUserBody body);

    /**
     * 根据条件分页查询已分配用户角色列表
     */
    Page<SysUserVo> selectAllocatedList(SysUserBody body);

    /**
     * 根据条件分页查询未分配用户角色列表
     */
    Page<SysUserVo> selectUnallocatedList(SysUserBody body);

    /**
     * 通过用户ID查询用户
     *
     * @param userId 用户ID
     * @return 用户对象信息
     */
    SysUserVo selectUserById(Long userId);

    /**
     * 根据用户ID查询用户所属角色组
     *
     * @param userName 用户名
     * @return 结果
     */
    String selectUserRoleGroup(String userName);

    /**
     * 校验用户是否有数据权限
     *
     * @param userId 用户id
     */
    void checkUserDataScope(Long userId);

    /**
     * 新增用户信息
     *
     * @param user 用户信息
     */
    boolean insertUser(SysUser user);

    /**
     * 修改用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    int updateUser(SysUser user);

    /**
     * 批量删除用户信息
     *
     * @param userIds 需要删除的用户ID
     */
    int deleteUserByIds(Long[] userIds);

    /**
     * 校验用户名称是否唯一
     */
    String checkUserNameUnique(Long userId, String userName);

    /**
     * 校验手机号码是否唯一
     */
    String checkPhoneUnique(Long userId, String phone);

    /**
     * 校验email是否唯一
     */
    String checkEmailUnique(Long userId, String email);

    /**
     * 查询用户活跃状态
     */
    UserActiveVo getUserActive();
}
