package com.zhiyun.project.system.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zhiyun.common.constant.UserConstants;
import com.zhiyun.common.utils.StringUtils;
import com.zhiyun.framework.RoleDataScope;
import com.zhiyun.project.system.domain.body.SysMenuBody;
import com.zhiyun.project.system.domain.entity.SysMenu;
import com.zhiyun.project.system.domain.vo.SysMenuVo;
import com.zhiyun.project.system.domain.vo.TreeSelect;
import com.zhiyun.project.system.mapper.SysMenuMapper;
import com.zhiyun.project.system.mapper.SysRoleMenuMapper;
import com.zhiyun.project.system.service.ISysMenuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * 菜单 业务层处理
 *
 * @author ruoyi
 */
@Service
public class SysMenuServiceImpl extends ServiceImpl<SysMenuMapper, SysMenu> implements ISysMenuService {

    @Autowired
    private SysRoleMenuMapper roleMenuMapper;

    @Override
    public List<SysMenuVo> selectMenuList(SysMenuBody body) {
        return baseMapper.selectMenuList(body);
    }

    @Override
    public Set<String> selectMenuPermsByUserId(Long userId) {
        return splitPrems(baseMapper.selectMenuPermsByUserId(userId));
    }

    @Override
    public Set<String> selectMenuPermsByRoleId(Long roleId) {
        return splitPrems(baseMapper.selectMenuPermsByRoleId(roleId));

    }

    private Set<String> splitPrems(List<String> perms) {
        Set<String> permsSet = new HashSet<>();
        for (String perm : perms) {
            if (StringUtils.isNotEmpty(perm)) {
                permsSet.addAll(Arrays.asList(perm.trim().split(",")));
            }
        }
        return permsSet;
    }

    @Override
    public List<SysMenuVo> selectMenuTreeByUserId(Long userId) {
        //管理员能看全部
        if (RoleDataScope.isAdmin(userId)) {
            userId = null;
        }
        List<SysMenuVo> menus = baseMapper.selectMenuTree(userId);
        List<SysMenuVo> tree = new ArrayList<>();
        for (SysMenuVo item : menus) {
            // 一、根据传入的某个父节点ID,遍历该父节点的所有子节点
            if (item.getParentId() == 0) {
                recurveFillChildMenu(menus, item);
                tree.add(item);
            }
        }
        return tree;
    }

    @Override
    public List<Long> selectMenuIdListByRoleId(Long roleId) {
//        SysRole role = roleMapper.selectById(roleId);
        return baseMapper.selectMenuIdListByRoleId(roleId, true);
    }

    @Override
    public List<TreeSelect> buildMenuTreeSelect(List<SysMenuVo> menus) {
        List<SysMenuVo> menuTrees = new ArrayList<>();
        Set<Long> tempSet = menus.stream().map(SysMenuVo::getMenuId).collect(Collectors.toSet());
        for (SysMenuVo menu : menus) {
            // 如果是顶级节点, 遍历该父节点的所有子节点
            if (!tempSet.contains(menu.getParentId())) {
                recurveFillChildMenu(menus, menu);
                menuTrees.add(menu);
            }
        }
        if (menuTrees.isEmpty()) {
            menuTrees = menus;
        }
        return menuTrees.stream().map(TreeSelect::new).collect(Collectors.toList());
    }

    @Override
    public boolean hasChildByMenuId(Long menuId) {
        int result = baseMapper.hasChildByMenuId(menuId);
        return result > 0;
    }

    @Override
    public boolean checkMenuExistRole(Long menuId) {
        return roleMenuMapper.checkMenuExistRole(menuId) > 0;
    }

    @Override
    public String checkMenuNameUnique(SysMenu menu) {
        long menuId = menu.getMenuId() == null ? -1L : menu.getMenuId();
        Long dbMenuId = baseMapper.checkMenuNameUnique(menu.getMenuName(), menu.getParentId());
        if (dbMenuId != null && dbMenuId != menuId) {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }

    /**
     * 递归填充子菜单
     *
     * @param allList 全部的菜单
     * @param menu    菜单
     */
    private void recurveFillChildMenu(List<SysMenuVo> allList, SysMenuVo menu) {
        // 得到子节点列表
        List<SysMenuVo> childList = getChildList(allList, menu.getMenuId());
        if (childList.isEmpty()) return;
        menu.setChildren(childList);
        for (SysMenuVo child : childList) {
            recurveFillChildMenu(allList, child);
        }
    }

    /**
     * 得到子节点列表
     */
    private List<SysMenuVo> getChildList(List<SysMenuVo> list, Long parentId) {
        return list.stream().filter(item -> item.getParentId().longValue() == parentId.longValue()).collect(Collectors.toList());
    }

}
